==> azure-search-documents-11.3.0b3.zip: azure-search-documents-11.3.0b3/azure/search/documents/models/__init__.py <==
# --------------------------------------------------------------------------
#
# Copyright (c) Microsoft Corporation. All rights reserved.
#
# The MIT License (MIT)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the ""Software""), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.
#
# --------------------------------------------------------------------------

from .._generated.models import (
    Answers,
    AnswerResult,
    AutocompleteMode,
    Captions,
    CaptionResult,
    IndexAction,
    IndexingResult,
    QueryLanguage,
    QueryType,
    SearchMode,
    Speller,
)
from .._search_client import odata


__all__ = (
    "Answers",
    "AnswerResult",
    "AutocompleteMode",
    "Captions",
    "CaptionResult",
    "IndexAction",
    "IndexingResult",
    "odata",
    "QueryLanguage",
    "QueryType",
    "SearchMode",
    "Speller",
)

==> azure-search-documents-11.4.0b6.zip: azure-search-documents-11.4.0b6/azure/search/documents/models/__init__.py <==
# --------------------------------------------------------------------------
#
# Copyright (c) Microsoft Corporation. All rights reserved.
#
# The MIT License (MIT)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the ""Software""), to
# deal in the Software without restriction, including without limitation the
# rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
# sell copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.
#
# --------------------------------------------------------------------------

from .._generated.models import (
    AnswerResult,
    AutocompleteMode,
    CaptionResult,
    IndexAction,
    IndexingResult,
    QueryAnswerType,
    QueryCaptionType,
    QueryLanguage,
    QuerySpellerType,
    QueryType,
    ScoringStatistics,
    SearchMode,
    SemanticErrorHandling,
    QueryDebugMode,
    Vector,
)
from .._utils import odata


__all__ = (
    "AnswerResult",
    "AutocompleteMode",
    "CaptionResult",
    "IndexAction",
    "IndexingResult",
    "odata",
    "QueryAnswerType",
    "QueryCaptionType",
    "QueryLanguage",
    "QuerySpellerType",
    "QueryType",
    "ScoringStatistics",
    "SearchMode",
    "SemanticErrorHandling",
    "QueryDebugMode",
    "Vector",
)
